pub struct CreateUserRequest {
pub email: String,
pub first_name: Option<String>,
pub id: Option<String>,
pub last_name: Option<String>,
pub name: LocalizedString,
pub password: Option<String>,
pub roles: Option<Map<String, Value>>,
}Expand description
CreateUserRequest
JSON schema
{
"type": "object",
"required": [
"email",
"name"
],
"properties": {
"email": {
"type": "string"
},
"first_name": {
"description": "Given name stored on the Kratos identity (`traits.name.first`) when creating the account.",
"type": [
"string",
"null"
]
},
"id": {
"description": "Optional ID parameter (admin-only, not documented in API docs)\nThis field is intentionally not included in OpenAPI documentation",
"type": [
"string",
"null"
]
},
"last_name": {
"description": "Family name stored on the Kratos identity (`traits.name.last`) when creating the account.",
"type": [
"string",
"null"
]
},
"name": {
"$ref": "#/components/schemas/LocalizedString"
},
"password": {
"description": "Optional password for Kratos identity (provisioning only; same permission as id).\nWhen set, the Kratos identity is created with this password so the user can log in immediately.",
"type": [
"string",
"null"
]
},
"roles": {
"description": "Org ID (string) to list of role names. Optional.",
"type": [
"object",
"null"
]
}
}
}Fields
email: Stringfirst_name: Option<String>Given name stored on the Kratos identity (traits.name.first) when creating the account.
id: Option<String>Optional ID parameter (admin-only, not documented in API docs) This field is intentionally not included in OpenAPI documentation
last_name: Option<String>Family name stored on the Kratos identity (traits.name.last) when creating the account.
name: LocalizedStringpassword: Option<String>Optional password for Kratos identity (provisioning only; same permission as id). When set, the Kratos identity is created with this password so the user can log in immediately.
roles: Option<Map<String, Value>>Org ID (string) to list of role names. Optional.