pub struct Device {
pub device_metadata: Option<Value>,
pub external_id: Option<String>,
pub id: String,
pub integration_id: String,
pub metadata: Option<HashMap>,
pub name: LocalizedString,
pub org_id: String,
}Expand description
A physical or virtual device belonging to an org and integration.
JSON schema
{
"description": "A physical or virtual device belonging to an org and integration.",
"type": "object",
"required": [
"id",
"integration_id",
"name",
"org_id"
],
"properties": {
"device_metadata": {
"description": "Device-specific JSON metadata (stored in Postgres `devices.metadata` JSONB column)."
},
"external_id": {
"description": "External ID from the integration provider.",
"type": [
"string",
"null"
]
},
"id": {
"description": "Unique identifier (ULID).",
"type": "string"
},
"integration_id": {
"description": "Owning integration (e.g. Shelly Cloud account/connection).",
"type": "string"
},
"metadata": {
"oneOf": [
{
"type": "null"
},
{
"oneOf": [
{
"$ref": "#/components/schemas/HashMap"
}
]
}
]
},
"name": {
"$ref": "#/components/schemas/LocalizedString"
},
"org_id": {
"description": "Organization that owns this device.",
"type": "string"
}
}
}Fields
device_metadata: Option<Value>Device-specific JSON metadata (stored in Postgres devices.metadata JSONB column).
external_id: Option<String>External ID from the integration provider.
id: StringUnique identifier (ULID).
integration_id: StringOwning integration (e.g. Shelly Cloud account/connection).
metadata: Option<HashMap>name: LocalizedStringorg_id: StringOrganization that owns this device.