pub struct Integration {
pub config: Option<Value>,
pub enabled: bool,
pub health: IntegrationHealth,
pub id: String,
pub metadata: Option<HashMap>,
pub name: LocalizedString,
pub org_id: String,
pub provider_type: ProviderType,
}Expand description
Credential/Auth for a specific cloud instance.
Example: Shelly account "A", HomeAssistant instance "Home".JSON schema
{
"description": "Credential/Auth for a specific cloud instance.\n\nExample: Shelly account \"A\", HomeAssistant instance \"Home\".",
"type": "object",
"required": [
"enabled",
"health",
"id",
"name",
"org_id",
"provider_type"
],
"properties": {
"config": {
"description": "Provider-specific non-secret configuration (JSON)."
},
"enabled": {
"description": "User-controlled flag: if false, this integration will not be used for actions/ops.",
"type": "boolean"
},
"health": {
"$ref": "#/components/schemas/IntegrationHealth"
},
"id": {
"description": "Unique identifier (ULID).",
"type": "string"
},
"metadata": {
"oneOf": [
{
"type": "null"
},
{
"oneOf": [
{
"$ref": "#/components/schemas/HashMap"
}
]
}
]
},
"name": {
"$ref": "#/components/schemas/LocalizedString"
},
"org_id": {
"description": "Organization that owns this integration.",
"type": "string"
},
"provider_type": {
"$ref": "#/components/schemas/ProviderType"
}
}
}Fields
config: Option<Value>Provider-specific non-secret configuration (JSON).
enabled: boolUser-controlled flag: if false, this integration will not be used for actions/ops.
health: IntegrationHealthid: StringUnique identifier (ULID).
metadata: Option<HashMap>name: LocalizedStringorg_id: StringOrganization that owns this integration.
provider_type: ProviderTypeTrait Implementations
Sourceimpl Clone for Integration
impl Clone for Integration
Sourcefn clone(&self) -> Integration
fn clone(&self) -> Integration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Integration
impl Debug for Integration
Sourceimpl<'de> Deserialize<'de> for Integration
impl<'de> Deserialize<'de> for Integration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more