pub struct MeApartmentAsset {Show 13 fields
pub apartment_label: Option<Value>,
pub apartment_number: Option<i64>,
pub building_name: Option<Value>,
pub call_eligible: bool,
pub display_name: Option<Value>,
pub dnd_enabled: Option<bool>,
pub entity_id: String,
pub floor: Option<Value>,
pub floor_number: Option<i64>,
pub integration_id: String,
pub org_id: String,
pub receives_calls: bool,
pub role: String,
}Expand description
MeApartmentAsset
JSON schema
{
"type": "object",
"required": [
"call_eligible",
"entity_id",
"integration_id",
"org_id",
"receives_calls",
"role"
],
"properties": {
"apartment_label": {},
"apartment_number": {
"type": [
"integer",
"null"
],
"format": "int64"
},
"building_name": {},
"call_eligible": {
"description": "True when this user would be a callee for intercom calls (policy + role + receives_calls).",
"type": "boolean"
},
"display_name": {},
"dnd_enabled": {
"description": "True when calls are silenced for this apartment (global DND or per-apartment DND).",
"type": [
"boolean",
"null"
]
},
"entity_id": {
"type": "string"
},
"floor": {},
"floor_number": {
"type": [
"integer",
"null"
],
"format": "int64"
},
"integration_id": {
"type": "string"
},
"org_id": {
"type": "string"
},
"receives_calls": {
"type": "boolean"
},
"role": {
"type": "string"
}
}
}Fields
apartment_label: Option<Value>apartment_number: Option<i64>building_name: Option<Value>call_eligible: boolTrue when this user would be a callee for intercom calls (policy + role + receives_calls).
display_name: Option<Value>dnd_enabled: Option<bool>True when calls are silenced for this apartment (global DND or per-apartment DND).
entity_id: Stringfloor: Option<Value>floor_number: Option<i64>integration_id: Stringorg_id: Stringreceives_calls: boolrole: StringTrait Implementations
Sourceimpl Clone for MeApartmentAsset
impl Clone for MeApartmentAsset
Sourcefn clone(&self) -> MeApartmentAsset
fn clone(&self) -> MeApartmentAsset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeApartmentAsset
impl Debug for MeApartmentAsset
Sourceimpl<'de> Deserialize<'de> for MeApartmentAsset
impl<'de> Deserialize<'de> for MeApartmentAsset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more