pub struct OrgPermissionsResponse {
pub permissions: Vec<String>,
}Expand description
Permissions the current user has in this org (for UI: gray out / tooltips). Returns a list of permission keys (e.g. “users:create”, “users:list”) that the user is granted.
JSON schema
{
"description": "Permissions the current user has in this org (for UI: gray out / tooltips).\nReturns a list of permission keys (e.g. \"users:create\", \"users:list\") that the user is granted.",
"type": "object",
"required": [
"permissions"
],
"properties": {
"permissions": {
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields
permissions: Vec<String>Trait Implementations
Sourceimpl Clone for OrgPermissionsResponse
impl Clone for OrgPermissionsResponse
Sourcefn clone(&self) -> OrgPermissionsResponse
fn clone(&self) -> OrgPermissionsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OrgPermissionsResponse
impl Debug for OrgPermissionsResponse
Sourceimpl<'de> Deserialize<'de> for OrgPermissionsResponse
impl<'de> Deserialize<'de> for OrgPermissionsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more