pub struct PublicInviteResponse {Show 14 fields
pub already_claimed: Option<bool>,
pub branding: Option<Value>,
pub building: Option<Value>,
pub grants: Vec<PublicInviteGrant>,
pub invite_token: String,
pub invitee_message: Option<Value>,
pub name: Option<String>,
pub schedule: Option<InviteScheduleSnapshot>,
pub schedule_combined: Option<InviteScheduleCombined>,
pub schedule_entries: Option<Vec<InviteScheduleEntrySnapshot>>,
pub schedule_kind: Option<InviteScheduleKind>,
pub state: PublicInviteState,
pub valid_from: Option<String>,
pub valid_to: Option<String>,
}Expand description
PublicInviteResponse
JSON schema
{
"type": "object",
"required": [
"grants",
"invite_token",
"state"
],
"properties": {
"already_claimed": {
"type": [
"boolean",
"null"
]
},
"branding": {},
"building": {
"description": "Building (integration) summary: `name` (LocalizedString) and optional `location` fields\nfrom integration config (`address`, `city`, `country`)."
},
"grants": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PublicInviteGrant"
}
},
"invite_token": {
"type": "string"
},
"invitee_message": {},
"name": {
"description": "Optional admin-defined label (management UI \"name\"); exposed for link previews and guests who already know the invite by name.",
"type": [
"string",
"null"
]
},
"schedule": {
"oneOf": [
{
"type": "null"
},
{
"oneOf": [
{
"$ref": "#/components/schemas/InviteScheduleSnapshot"
}
]
}
]
},
"schedule_combined": {
"oneOf": [
{
"type": "null"
},
{
"oneOf": [
{
"$ref": "#/components/schemas/InviteScheduleCombined"
}
]
}
]
},
"schedule_entries": {
"type": [
"array",
"null"
],
"items": {
"$ref": "#/components/schemas/InviteScheduleEntrySnapshot"
}
},
"schedule_kind": {
"oneOf": [
{
"type": "null"
},
{
"oneOf": [
{
"$ref": "#/components/schemas/InviteScheduleKind"
}
]
}
]
},
"state": {
"$ref": "#/components/schemas/PublicInviteState"
},
"valid_from": {
"type": [
"string",
"null"
]
},
"valid_to": {
"type": [
"string",
"null"
]
}
}
}Fields
already_claimed: Option<bool>branding: Option<Value>building: Option<Value>Building (integration) summary: name (LocalizedString) and optional location fields
from integration config (address, city, country).
grants: Vec<PublicInviteGrant>invite_token: Stringinvitee_message: Option<Value>name: Option<String>Optional admin-defined label (management UI “name”); exposed for link previews and guests who already know the invite by name.
schedule: Option<InviteScheduleSnapshot>schedule_combined: Option<InviteScheduleCombined>schedule_entries: Option<Vec<InviteScheduleEntrySnapshot>>schedule_kind: Option<InviteScheduleKind>state: PublicInviteStatevalid_from: Option<String>valid_to: Option<String>Trait Implementations
Sourceimpl Clone for PublicInviteResponse
impl Clone for PublicInviteResponse
Sourcefn clone(&self) -> PublicInviteResponse
fn clone(&self) -> PublicInviteResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublicInviteResponse
impl Debug for PublicInviteResponse
Sourceimpl<'de> Deserialize<'de> for PublicInviteResponse
impl<'de> Deserialize<'de> for PublicInviteResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more